@@ -10,9 +10,17 @@ CreateTrainTestSet <- function(data, fractionTrain=0.5, type="regression"){
     test <- list(x=data$x[,-selecttrain], y=data$y[-selecttrain])
   } else if (type=="two class"){
     whichers <- which(data$y==1)
-    testindices <- sample(whichers, floor(length(whichers)/2))
+    testindices <- sample(whichers, floor(length(whichers)*(1-fractionTrain)))
     whichers <- which(data$y==2)
-    testindices <- c(testindices, sample(whichers, floor(length(whichers)/2)))
+    testindices <- c(testindices, sample(whichers, floor(length(whichers)*(1-fractionTrain))))
+    train <- list(x=data$x[,-testindices], y=data$y[-testindices])
+    test <- list(x=data$x[,testindices], y=data$y[testindices])
+  } else if (type=="multiclass"){
+    testindices <- NULL
+    for(i in unique(data$y)){
+      whichers <- which(data$y==i)
+      testindices <- c(testindices, sample(whichers, floor(length(whichers))*(1-fractionTrain)))
+    }
     train <- list(x=data$x[,-testindices], y=data$y[-testindices])
     test <- list(x=data$x[,testindices], y=data$y[testindices])
   } else stop("Not an acceptable type.")
